<?php

/**
 * Description of turma
 *
 * @author joaog
 */
class Turma {

    private $ano;
    private $semestre;
    private $idprofessor;
    private $idturma;
    private $iddisciplina;
    private $status;
    private $connection;

    public function __construct($row) {
        $this->ano = $row['tur_ano'];
        $this->semestre = $row['tur_semestre'];
        $this->idprofessor = $row['prof_id'];
        $this->idturma = $row['idTurma'];
        $this->iddisciplina = $row['disc_id'];
        $this->status = $row['status'];
        $controlador = new ControladorUsuario();
        $this->connection = $controlador->getConnection();
    }

    public function getStatus() {
        return $this->status;
    }

    public function getAno() {
        return $this->ano;
    }

    public function getSemestre() {
        return $this->semestre;
    }

    public function getIdprofessor() {
        return $this->idprofessor;
    }

    public function getIdturma() {
        return $this->idturma;
    }

    public function getIddisciplina() {
        return $this->iddisciplina;
    }

    public function listarTopicos($ini, $fim) {
        $lista = null;
        try {
            $stmt = $this->connection->prepare('SELECT * FROM topico WHERE `Turma_idTurma`=:id ORDER BY data DESC,hora DESC LIMIT :ini,:fim ');
            $stmt->bindParam(':ini', $ini, PDO::PARAM_INT);
            $stmt->bindParam(':fim', $fim, PDO::PARAM_INT);
            $stmt->bindParam(':id', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new Topico($result);
                }
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return $lista;
    }

    public function getTotalArquivo($idatv, $isAluno, $iduser) {
        $result = null;
        try {
            if (!$isAluno) {
                $stmt = $this->connection->prepare('SELECT count(arq_id) as total FROM arquivo WHERE idatividade=:idatv');
            } else {
                $stmt = $this->connection->prepare('SELECT count(arq_id) as total FROM arquivo WHERE idatividade=:idatv AND (idusuario=:idprof OR idusuario=:iduser)');
                $stmt->bindParam(':idprof', $this->idprofessor, PDO::PARAM_INT);
                $stmt->bindParam(':iduser', $iduser, PDO::PARAM_INT);
            }
            $stmt->bindParam(':idatv', $idatv, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $fecth = $stmt->fetch(PDO::FETCH_ASSOC);
                $result = (int) $fecth['total'];
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return $result;
    }

    public function getArquivo($id) {
        $result = null;
        try {

            $stmt = $this->connection->prepare('SELECT * FROM arquivo WHERE arq_id=:id');
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $result = new Arquivo($stmt->fetch(PDO::FETCH_ASSOC));
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return $result;
    }

    public function listarArquivosAbertosDaAtividade($idatv) {
        $lista = null;
        try {
            $stmt = $this->connection->prepare('SELECT arquivo.* FROM arquivo,atividade,turma WHERE '
                    . 'arquivo.idatividade=:idatv AND '
                    . 'atividade.idTurma = turma.idTurma AND '
                    . 'arquivo.idatividade=atividade.atv_id '
                    . 'AND atividade.`idTurma`=:idturma '
                    . 'AND turma.prof_id=arquivo.idusuario');

            $idturma = (int) $this->idturma;

            $stmt->bindParam(':idturma', $idturma, PDO::PARAM_INT);
            $stmt->bindParam(':idatv', $idatv, PDO::PARAM_INT);

            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new Arquivo($result);
                }
            }
        } catch (Exception $e) {
            echo $e->getMessage();
        }

        return $lista;
    }

    public function listarArquivosDaAtividade($idatv) {
        $lista = null;
        try {
            $stmt = $this->connection->prepare('SELECT arquivo.* FROM arquivo,atividade,turma WHERE '
                    . 'arquivo.idatividade=:idatv AND '
                    . 'atividade.idTurma = turma.idTurma AND '
                    . 'arquivo.idatividade=atividade.atv_id '
                    . 'AND atividade.`idTurma`=:idturma '
                    . 'AND turma.prof_id!=arquivo.idusuario');


            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':idatv', $idatv, PDO::PARAM_INT);

            if ($stmt->execute()) {
                $lista = array();
                $cont = 0;

                $controlador = new ControladorUsuario();

                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[$cont] = new Arquivo($result);

                    $stmt2 = $this->connection->prepare('SELECT usu_fname,usu_lname,usu_nickname,email FROM usuario WHERE usu_id=:id');
                    $stmt2->bindParam(':id', $result['idusuario'], PDO::PARAM_INT);
                    $stmt2->execute();
                    $aluno = $stmt2->fetch(PDO::FETCH_ASSOC);
                    $lista[$cont]->setTitleAluno($controlador->getTitleNameBy($aluno['usu_fname'], $aluno['usu_lname'], $aluno['usu_nickname'], $aluno['email']));

                    $cont++;
                }
            }
        } catch (Exception $e) {
            echo $e->getMessage();
        }

        return $lista;
    }

    public function novoArquivo($descricao, $idusuario, $file, $idatividade) {

        try {

            $stmt = $this->connection->prepare('INSERT INTO arquivo (`descricao`, `idusuario`, `idatividade`, `data`, `hora`) VALUES (:descricao,:iduser,:idatv,current_date(),current_time())');
            $stmt->bindParam(':descricao', $descricao, PDO::PARAM_STR);
            $stmt->bindParam(':iduser', $idusuario, PDO::PARAM_INT);
            $stmt->bindParam(':idatv', $idatividade, PDO::PARAM_INT);
            $a = $stmt->execute();

            $stmt = $this->connection->prepare('SELECT last_insert_id() as id');
            $stmt->execute();
            $fecth = $stmt->fetch(PDO::FETCH_ASSOC);
            $lastid = (int) $fecth['id'];

            $target_dir = 'files/' . $lastid . '_' . $file["name"];

            move_uploaded_file($file["tmp_name"], $target_dir);
            if (file_exists($target_dir)) {
                $stmt = $this->connection->prepare('UPDATE arquivo SET `caminho`=:url WHERE `arquivo`.`arq_id`=:id');
                $stmt->bindParam(':url', $target_dir, PDO::PARAM_STR);
                $stmt->bindParam(':id', $lastid, PDO::PARAM_INT);
                $b = $stmt->execute();
                return $a && $b;
            } else {
                $stmt = $this->connection->prepare('DELETE FROM arquivo WHERE arq_id = :id');
                $stmt->bindParam(':id', $lastid, PDO::PARAM_STR);
                $stmt->execute();
            }
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
        return false;
    }

    public function updateAtividade($idatv, $titulo, $texto, $data) {
        try {
            $stmt = $this->connection->prepare('UPDATE atividade SET atv_hora=current_time(), atv_data=current_date(), `atv_data_limite`=:data, `atv_titulo`=:titulo, `atv_texto`=:texto WHERE `atv_id`=:idatv and `idTurma`=:idturma');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':idatv', $idatv, PDO::PARAM_INT);
            $stmt->bindParam(':texto', $texto, PDO::PARAM_STR);
            $stmt->bindParam(':titulo', $titulo, PDO::PARAM_STR);
            $stmt->bindParam(':data', $data, PDO::PARAM_STR);
            return $stmt->execute();
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
        return false;
    }

    public function deleteAtividade($idatv) {

        try {
            $stmt = $this->connection->prepare('DELETE FROM atividade WHERE `atv_id`=:idatv AND `idTurma`=:idturma');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':idatv', $idatv, PDO::PARAM_INT);
            return $stmt->execute();
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return false;
    }

    public function getAtividade($idatv) {
        $atividade = null;
        try {
            $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE `idTurma`=:idturma AND atv_id=:idatv');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':idatv', $idatv, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $result = $stmt->fetch(PDO::FETCH_ASSOC);
                if ($result) {
                    return new Atividade($result);
                }
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return $atividade;
    }

    public function setPermission($idestrutura, $pseudo, $value) {
        $result = false;
        try {

            $stmt = $this->connection->prepare('SELECT * FROM permissoes WHERE Turma_idTurma=:idturma AND ed_id=:ided');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':ided', $idestrutura, PDO::PARAM_INT);
            $a = $stmt->execute();
            $row = $stmt->fetch(PDO::FETCH_ASSOC);

            if (!$row) {
                $stmt = $this->connection->prepare('INSERT INTO permissoes(ed_id,Turma_idTurma) VALUES (:ided,:idturma)');
                $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
                $stmt->bindParam(':ided', $idestrutura, PDO::PARAM_INT);
                $b = $stmt->execute();
                $stmt = $this->connection->prepare('SELECT * FROM permissoes WHERE Turma_idTurma=:idturma AND ed_id=:ided');
                $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
                $stmt->bindParam(':ided', $idestrutura, PDO::PARAM_INT);
                $c = $stmt->execute();
                $row = $stmt->fetch(PDO::FETCH_ASSOC);
                $idpermissao = (int) $row['idpermissao'];
            } else {
                $b = $c = true;
            }

            $idpermissao = (int) $row['idpermissao'];
            switch ($pseudo) {
                case 'add':$sql = 'UPDATE permissoes SET pseudo_add=:value WHERE idpermissao=:idpermissao';
                    break;
                case 'rem':$sql = 'UPDATE permissoes SET pseudo_rem=:value WHERE idpermissao=:idpermissao';
                    break;
                case 'search':$sql = 'UPDATE permissoes SET pseudo_search=:value WHERE idpermissao=:idpermissao';
                    break;
            }
            $stmt = $this->connection->prepare($sql);
            $stmt->bindParam(':idpermissao', $idpermissao, PDO::PARAM_INT);
            $stmt->bindParam(':value', $value, PDO::PARAM_BOOL);
            $d = $stmt->execute();
        } catch (PDOException $e) {
            echo $e;
        }
        return $a && $b && $c & $d;
    }

    public function obterPermissoes($idestrutura) {
        $result = false;
        try {
            $stmt = $this->connection->prepare('SELECT * FROM permissoes WHERE Turma_idTurma=:idturma AND ed_id=:ided');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':ided', $idestrutura, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $row = $stmt->fetch(PDO::FETCH_ASSOC);
                if ($row) {
                    $result = array('add' => ($row['pseudo_add'] === '1'), 'rem' => ($row['pseudo_rem'] === '1'), "search" => ($row['pseudo_search'] === '1'));
                } else {
                    $result = array('add' => false, 'rem' => false, "search" => false);
                }
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return $result;
    }

    public function removerLink($idlink) {
        try {
            $stmt = $this->connection->prepare('DELETE FROM link WHERE link_id=:idlink;');
            $stmt->bindParam(':idlink', $idlink, PDO::PARAM_INT);
            return $stmt->execute();
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return false;
    }

    public function novoLink($titulo, $url) {
        try {
            $stmt = $this->connection->prepare('INSERT INTO link(path,nome,Turma_idTurma) VALUES (:url,:titulo,:idturma)');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':titulo', $titulo, PDO::PARAM_STR);
            $stmt->bindParam(':url', $url, PDO::PARAM_STR);
            return $stmt->execute();
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return false;
    }

    public function listarLinks() {
        try {
            $stmt = $this->connection->prepare('SELECT * FROM link WHERE Turma_idTurma=:idturma');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new Link($result);
                }
                return $lista;
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function getTotalAtividadesAbertas() {
        try {

            $stmt = $this->connection->prepare('SELECT count(atv_id) as total FROM atividade WHERE idTurma=:idturma AND atv_data_limite>=current_date()');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $fecth = $stmt->fetch(PDO::FETCH_ASSOC);
                return (int) $fecth['total'];
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return -1;
    }

    public function listarAtividadesAbertas($order) {
        try {
            if ($order === 'revisao') {
                $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE idTurma=:idturma AND atv_data_limite>=current_date() ORDER BY atividade.atv_data , atividade.atv_hora');
            } else if ($order === 'entrega') {
                $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE idTurma=:idturma AND atv_data_limite>=current_date() ORDER BY atividade.atv_data_limite DESC');
            }
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new Atividade($result);
                }
                return array_reverse($lista);
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function listarAtividadesFechadas($order) {
        try {
            if ($order === 'revisao') {
                $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE idTurma=:idturma AND atv_data_limite<current_date() ORDER BY atividade.atv_data , atividade.atv_hora');
            } else if ($order === 'entrega') {
                $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE idTurma=:idturma AND atv_data_limite<current_date() ORDER BY atividade.atv_data_limite');
            }
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new Atividade($result);
                }
                return array_reverse($lista);
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function listarAtividades($order) {
        try {
            if ($order === 'revisao') {
                $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE idTurma=:idturma ORDER BY atividade.atv_data , atividade.atv_hora');
            } else if ($order === 'entrega') {
                $stmt = $this->connection->prepare('SELECT * FROM atividade WHERE idTurma=:idturma ORDER BY atividade.atv_data_limite');
            }
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new Atividade($result);
                }
                return array_reverse($lista);
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function novaAtividade($titulo, $texto, $data) {
        try {

            $stmt = $this->connection->prepare('call novaAtividade(:data,:titulo,:texto,:idturma)');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':texto', $texto, PDO::PARAM_STR);
            $stmt->bindParam(':titulo', $titulo, PDO::PARAM_STR);
            $stmt->bindParam(':data', $data, PDO::PARAM_STR);
            if ($stmt->execute()) {
                $fecth = $stmt->fetch(PDO::FETCH_ASSOC);
                return (int) $fecth['id'];
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return false;
    }

    public function setStatus($status) {
        try {
            $stmt = $this->connection->prepare('UPDATE turma SET status=:text WHERE idTurma=:idturma;');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->bindParam(':text', $status, PDO::PARAM_STR);
            return $stmt->execute();
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return false;
    }

    public function listarPermissoes() {
        try {

            $stmt = $this->connection->prepare('SELECT * FROM permissoes WHERE Turma_idTurma=:idturma');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[(int) $result['ed_id']] = new Permissao($result);
                }
                return $lista;
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function getAlunos() {
        try {

            $stmt = $this->connection->prepare('SELECT usuario.*,aluno.*,configuracoes.Path_imguser FROM aluno,usuario,configuracoes WHERE usuario.usu_id=aluno.alu_id AND aluno.idTurma=:idturma AND configuracoes.Usuario_usu_id=aluno.alu_id');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->execute();
            $lista = array();
            while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                $imageurl = $result['Path_imguser'];
                if ($imageurl != null && $imageurl != '') {
                    $imageurl = $imageurl . '?=' . rand();
                } else {
                    $imageurl = 'images/userdefault.png';
                }
                $lista[] = array('id' => $result['usu_id'], 'image' => $imageurl, 'data_cadastro' => date("d/m/Y", strtotime($result['dia_cadastro'])), 'email' => $result['email'], 'nome' => $result['usu_fname'], 'sobrenome' => $result['usu_lname'], 'apelido' => $result['usu_nickname']);
            }
            return $lista;
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function getSolicitacoes() {
        try {

            $stmt = $this->connection->prepare('SELECT usuario.* ,idsolicitacao,configuracoes.Path_imguser FROM solicitacao,usuario,configuracoes WHERE usuario.usu_id=solicitacao.Aluno_alu_id AND solicitacao.Turma_idTurma=:idturma AND configuracoes.Usuario_usu_id=solicitacao.Aluno_alu_id');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $imageurl = $result['Path_imguser'];

                    if ($imageurl != null && $imageurl != '') {
                        $imageurl = $imageurl . '?=' . rand();
                    } else {
                        $imageurl = 'images/userdefault.png';
                    }

                    $lista[] = array('image' => $imageurl, 'data_cadastro' => $result['dia_cadastro'], 'email' => $result['email'], 'nome' => $result['usu_fname'], 'sobrenome' => $result['usu_lname'], 'apelido' => $result['usu_nickname'], 'id' => $result['idsolicitacao']);
                }
                return $lista;
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function resultSQL($sql) {
        $stmt = $this->connection->prepare($sql);
        $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
        $stmt->execute();
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function getDescricaoTurma() {
        try {
            $result = $this->resultSQL('call detailTurma(:idturma);');
            $infos = array
                (
                'disciplina_nome' => $result['disc_nome'],
                'curso_nome' => $result['cur_nome'],
                'curso_sigla' => $result['cur_sigla'],
                'instituicao_nome' => $result['inst_nome'],
                'instituicao_uf' => $result['inst_uf'],
                'professor_email' => $result['email'],
                'professor_nome' => $result['usu_fname'],
                'professor_sobrenome' => $result['usu_fname'],
                'professor_apelido' => $result['usu_nickname']
            );
            $dadoAlunos = $this->resultSQL('SELECT count(aluno.alu_id) AS total_alunos FROM aluno WHERE aluno.idTurma=:idturma');
            $dadoAtividades = $this->resultSQL('SELECT count(atividade.atv_id) AS total_atividades FROM atividade WHERE atividade.idTurma=:idturma');
            $dadoSolicitacoes = $this->resultSQL('SELECT count(solicitacao.idsolicitacao) AS total_solicitacoes FROM solicitacao WHERE solicitacao.Turma_idTurma=:idturma');
            
            $infos['total_alunos'] = $dadoAlunos['total_alunos'];
            $infos['total_atividades'] = $dadoAtividades['total_atividades'];
            $infos['total_solicitacoes'] = (int) $dadoSolicitacoes['total_solicitacoes'];

            return $infos;
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function getTotalTopicos() {
        try {
            $stmt = $this->connection->prepare('SELECT count(top_id) AS total FROM topico WHERE `Turma_idTurma`=:idturma');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $fecth = $stmt->fetch(PDO::FETCH_ASSOC);
                return (int) $fecth['total'];
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return -1;
    }

    public function deleteArquivosAtividade($id) {
        try {
            $stmt = $this->connection->prepare('SELECT caminho,arq_id FROM arquivo WHERE idatividade=:idatv');
            $stmt->bindParam(':idatv', $id, PDO::PARAM_INT);
            $stmt->execute();
            while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                try {
                    $stmt = $this->connection->prepare('DELETE FROM arquivo WHERE arq_id=:idarq');
                    $stmt->bindParam(':idarq', $result['arq_id'], PDO::PARAM_INT);
                    $stmt->execute();
                } catch (PDOException $e) {
                    echo $e->getMessage();
                    continue;
                }
                unlink($result['caminho']);
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
            return false;
        }
        return true;
    }

    public function novoMaterialDidatico($titulo, $detalhes, $file) {
        try {

            $stmt = $this->connection->prepare('INSERT INTO materialdidatico(rotulo,detalhes,`data`,hora,`Turma_idTurma`) VALUES (:rotulo,:detalhes,current_date(),current_time(),:idturma)');
            $stmt->bindParam(':detalhes', $detalhes, PDO::PARAM_STR);
            $stmt->bindParam(':rotulo', $titulo, PDO::PARAM_INT);
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            $stmt->execute();

            $stmt = $this->connection->prepare('SELECT last_insert_id() as id');
            $stmt->execute();
            $fecth = $stmt->fetch(PDO::FETCH_ASSOC);
            $lastid = (int) $fecth['id'];

            $target_dir = 'materiais/' . $lastid . '_' . $file["name"];

            move_uploaded_file($file["tmp_name"], $target_dir);
            $stmt = $this->connection->prepare('UPDATE materialdidatico SET `pathArquivo`=:url WHERE materialdidatico.`idMaterialDidatico`=:id');
            $stmt->bindParam(':url', $target_dir, PDO::PARAM_STR);
            $stmt->bindParam(':id', $lastid, PDO::PARAM_INT);

            return $stmt->execute();
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
        return false;
    }

    public function listarMateriaisDidaticos() {
        try {

            $stmt = $this->connection->prepare('SELECT * FROM materialdidatico WHERE Turma_idTurma=:idturma');
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                $lista = array();
                while ($result = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new MaterialDidatico($result);
                }
                return $lista;
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function getMaterial($id) {
        try {

            $stmt = $this->connection->prepare('SELECT * FROM materialdidatico WHERE `idMaterialDidatico`=:id AND `Turma_idTurma`=:idturma');
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            if ($stmt->execute()) {
                return new MaterialDidatico($stmt->fetch(PDO::FETCH_ASSOC));
            }
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return null;
    }

    public function deletarMaterial($id) {

        try {
            $stmt = $this->connection->prepare('delete FROM materialdidatico WHERE `idMaterialDidatico`=:id AND `Turma_idTurma`=:idturma');
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->bindParam(':idturma', $this->idturma, PDO::PARAM_INT);
            return $stmt->execute();
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
        return false;
    }

}
