<?php

namespace controladores;

use controladores\PDOCadilag;
use PDO;

class CodePDO extends PDOCadilag {

    public function insertStmt($idEstruturaDeDados, $title, $language, $jsonAdd, $jsonRem, $jsonSearch) {
        $stmt = $this->prepare(
                'INSERT INTO `codigo` (`titulo`, `linguagem`,`idUser`,`idEstrutura`,`jsonAdd`,`jsonRem`,`jsonSearch`) '
                . 'VALUES (:titulo,:language,:idUser,:idEstrutura,:jsonAdd,:jsonRem,:jsonSearch)');
        $stmt->bindValue(':idUser', $this->idUser, PDO::PARAM_INT);
        $stmt->bindValue(':idEstrutura', $idEstruturaDeDados, PDO::PARAM_INT);
        $stmt->bindValue(':titulo', $title, PDO::PARAM_STR);
        $stmt->bindValue(':language', $language, PDO::PARAM_STR);
        $stmt->bindValue(':jsonAdd', $jsonAdd, PDO::PARAM_STR);
        $stmt->bindValue(':jsonRem', $jsonRem, PDO::PARAM_STR);
        $stmt->bindValue(':jsonSearch', $jsonSearch, PDO::PARAM_STR);
        return $stmt;
    }

    public function updateStmt($idCode, $title, $language, $jsonAdd, $jsonRem, $jsonSearch) {
        if ($title && $language) {
            $stmt = $this->prepare('UPDATE `codigo` SET `titulo` = :titulo, linguagem = :language, `jsonAdd` = :jsonAdd, `jsonRem` = :jsonRem, `jsonSearch` = :jsonSearch, datetime = NOW() '
                    . 'WHERE id = :idCode AND `idUser` = :idUser');
            $stmt->bindValue(':titulo', $title, PDO::PARAM_STR);
            $stmt->bindValue(':language', $language, PDO::PARAM_STR);
        } else {
            $stmt = $this->prepare('UPDATE `codigo` SET `jsonAdd` = :jsonAdd, `jsonRem` = :jsonRem, `jsonSearch` = :jsonSearch, datetime = NOW() '
                    . 'WHERE id = :idCode AND `idUser` = :idUser');
        }
        $stmt->bindValue(':idUser', $this->idUser, PDO::PARAM_INT);
        $stmt->bindValue(':idCode', $idCode, PDO::PARAM_INT);
        $stmt->bindValue(':jsonAdd', $jsonAdd, PDO::PARAM_STR);
        $stmt->bindValue(':jsonRem', $jsonRem, PDO::PARAM_STR);
        $stmt->bindValue(':jsonSearch', $jsonSearch, PDO::PARAM_STR);
        return $stmt;
    }

    public function descriptionStmt($idCode) {
        $stmt = $this->prepare("SELECT * FROM codigo WHERE codigo.id = :idCode");
        $stmt->bindValue(':idCode', $idCode, PDO::PARAM_STR);
        return $stmt;
    }

    public function listOwnStmt($idEstrutura) {
        $stmt = $this->prepare('SELECT '
                . 'c.titulo as "rotulo" '
                . ',c.linguagem as "linguagem" '
                . ',c.datetime as "datetime" '
                . ',c.id as "id" '
                . 'FROM codigo c '
                . 'WHERE c.`idUser` = :idUser AND '
                . 'c.`idEstrutura` = :idEstrutura');
        $stmt->bindValue(':idUser', $this->idUser, PDO::PARAM_INT);
        $stmt->bindValue(':idEstrutura', $idEstrutura, PDO::PARAM_INT);
        return $stmt;
    }

    public function listStmt($idestrutura) {
        $stmt = $this->prepare(
                'SELECT u.usu_fname as "fname"'
                . ',u.usu_lname as "lname"'
                . ',u.usu_nickname as "nickname"'
                . ',u.email as "email" '
                . ',c.idUser as "iduser"'
                . ',c.titulo as "titulo"'
                . ',c.linguagem as "linguagem"'
                . ',c.datetime as "datetime"'
                . ',c.id as "idCode"'
                . 'FROM codigo c '
                . 'INNER JOIN usuario u ON u.usu_id = c.idUser '
                . 'WHERE c.idEstrutura = :idEstrutura');
        $stmt->bindValue(':idEstrutura', $idestrutura, PDO::PARAM_INT);
        return $stmt;
    }

    public function codeStmt($idCode) {
        $stmt = $this->prepare('SELECT `jsonAdd` as addCode,`jsonRem` as remCode,`jsonSearch` as searchCode FROM codigo WHERE `idUser` = :idUser AND id = :idCode');
        $stmt->bindValue(':idUser', $this->idUser, PDO::PARAM_INT);
        $stmt->bindValue(':idCode', $idCode, PDO::PARAM_INT);
        return $stmt;
    }

    public function deleteStmt($idCode) {
        $stmt = $this->prepare('DELETE FROM codigo WHERE `idUser` = :idUser AND id = :idCode');
        $stmt->bindValue(':idCode', $idCode, PDO::PARAM_INT);
        $stmt->bindValue(':idUser', $this->idUser, PDO::PARAM_INT);
        return $stmt;
    }

    public function codeDetailStmt($idCode) {
        $stmt = $this->prepare("SELECT idEstrutura as idEstrutura,titulo as title,linguagem as language FROM codigo WHERE codigo.id = :idCode AND codigo.`idUser` = :idUser");
        $stmt->bindValue(':idCode', $idCode, PDO::PARAM_INT);
        $stmt->bindValue(':idUser', $this->idUser, PDO::PARAM_INT);
        return $stmt;
    }

}
