<?php

namespace controladores;

use PDO;
use config\Database;

class ControladorCodigos {

    private $connection;

    public function __construct() {
        try {
            $this->connection = new CodePDO(
                    'mysql:host=localhost;dbname=' . Database::$mysql_dbname, Database::$mysql_user, Database::$mysql_password
            );
        } catch (PDOException $e) {
            echo '<code>' . $e->getMessage() . '</code>';
            die();
        }
    }

    public function checkAcess($email, $password) {
        return $this->connection->checkAcess($email, $password);
    }

    public function registerNewCode($idEstruturaDeDados, $title, $language, $listaAdd, $listaRem, $listaSearch) {
        try {
            $stmt = $this->connection->insertStmt($idEstruturaDeDados, $title, $language, $listaAdd, $listaRem, $listaSearch);
            if ($stmt->execute()) {
                return array("success" => true, "reply" => "Sucesso ao executar o Script");
            } else {
                return array("success" => false, "reply" => "Falha ao executar o Script");
            }
        } catch (PDOException $e) {
            return array("success" => false, "reply" => $e->getMessage());
        }
    }

    public function updateCode($idCode, $title, $language, $listaAdd, $listaRem, $listaSearch) {
        try {
            $stmt = $this->connection->updateStmt($idCode, $title, $language, $listaAdd, $listaRem, $listaSearch);
            if ($stmt->execute()) {
                return array("success" => true, "reply" => "Sucesso ao executar o Script");
            } else {
                return array("success" => false, "reply" => "Falha ao executar o Script");
            }
        } catch (PDOException $e) {
            return array("success" => false, "reply" => $e->getMessage());
        }
    }

    public function deleteCode($idCode) {
        try {
            $stmt = $this->connection->deleteStmt($idCode);
            if ($stmt->execute()) {
                return array("success" => true, "reply" => "Sucesso ao executar o Script");
            } else {
                return array("success" => false, "reply" => "Falha ao executar o Script");
            }
        } catch (PDOException $e) {
            return array("success" => false, "reply" => $e->getMessage());
        }
    }

    public function getCodes($idCode) {
        try {
            $stmt = $this->connection->codeStmt($idCode);

            if ($stmt->execute() && $stmt->rowCount() == 1) {
                $result = $stmt->fetch(PDO::FETCH_ASSOC);
                return array("success" => true, "add" => $result['addCode'], "rem" => $result['remCode'], "search" => $result['searchCode'], "reply" => "Sucesso ao executar o Script");
            } else {
                return array("success" => false, "reply" => "Falha ao executar o Script");
            }
        } catch (PDOException $e) {
            return array("success" => false, "reply" => $e->getMessage());
        }
    }

    public function getCodeDetail($idCode) {
        try {
            $stmt = $this->connection->codeDetailStmt($idCode);
            $resultPDO = $stmt->execute();
            if ($resultPDO && $stmt->rowCount() == 1) {
                $result = $stmt->fetch(PDO::FETCH_ASSOC);
                return array("success" => true, "reply" => "Sucesso na execução do SQL","idEstrutura" => $result['idEstrutura'], "title" => $result['title'], "language" => $result['language']);
            } else {
                return array("success" => false, "reply" => "Erro na execução do SQL");
            }
        } catch (Exception $ex) {
            return array("success" => false, "reply" => $ex->getMessage());
        }
    }

    public function listCodes($idEstrutura) {
        try {
            $stmt = $this->connection->listStmt($idEstrutura);
            if ($stmt->execute()) {
                return array("success" => true, "reply" => "Sucesso na execução do SQL", "lista" => $stmt->fetchAll(PDO::FETCH_ASSOC));
            } else {
                return array("success" => false, "reply" => "Erro na execução do SQL");
            }
        } catch (PDOException $e) {
            return array("success" => false, "reply" => $e->getMessage());
        }
    }

    public function listOwnCodes($idEstrutura) {
        try {
            $stmt = $this->connection->listOwnStmt($idEstrutura);
            if ($stmt->execute()) {
                $lista = array();
                while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $lista[] = new \entidades\Codigo($row);
                }
                return array("success" => true, "reply" => "Sucesso na execução do SQL", "lista" => $lista);
            } else {
                return array("success" => false, "reply" => "Erro na execução do SQL");
            }
        } catch (PDOException $e) {
            return array("success" => false, "reply" => $e->getMessage());
        }
    }

}
